@@ -62,6 +62,11 @@ class UrlLocation(object):
             return True
         return False
 
+    def is_onion(self):
+        domain = self.get_domain()
+        if domain:
+            return domain.endswith(".onion")
+
     def get_protocolless(self):
         protocol_pos = self.url.find("://")
         if protocol_pos >= 0:
@@ -98,6 +103,8 @@ class UrlLocation(object):
         protocol_pos = self.url.find("://")
         if protocol_pos >= 0:
             return protocol + "://" + self.url[protocol_pos + 3 :]
+        else:
+            return protocol + "://" + self.url
 
         return self.url
 
@@ -119,7 +126,10 @@ class UrlLocation(object):
             return self.parse_netloc("\\\\")
 
         else:
-            return ["https", "://", self.url]
+            if self.url.endswith(".onion"):
+                return ["http", "://", self.url]
+            else:
+                return ["https", "://", self.url]
 
     def parse_protocoled_url(self):
         protocol_pos = self.url.find("://")
@@ -226,6 +236,9 @@ class UrlLocation(object):
 
         @return domain.com
         """
+        if not self.url:
+            return
+
         parts = self.parse_url()
         if parts:
             return parts[2].lower()
@@ -242,6 +255,9 @@ class UrlLocation(object):
         if not self.url:
             return False
 
+        if self.is_onion():
+            return False
+
         url = self.get_full_url()
         if url == self.get_domain():
             return True
@@ -289,9 +305,12 @@ class UrlLocation(object):
             url = url[:-1]
 
         p = UrlLocation(url)
+
+        if p.is_onion():
+            return p.url
+
         domain = p.get_domain()
         if not domain:
-            WebLogger.error("Could not obtain domain for:{}".format(url))
             return
 
         domain_lower = domain.lower()
@@ -615,6 +634,9 @@ class UrlLocation(object):
         # if not found, we return none
 
     def get_robots_txt_url(self):
+        if self.is_onion():
+            return
+
         return self.get_domain() + "/robots.txt"
 
     def is_link_in_domain(self, address):
